==> huaweicloudsdkcdn-3.0.50-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/cache_config.py <==
# coding: utf-8

import pprint
import re

import six





class CacheConfig:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'ignore_url_parameter': 'bool',
        'follow_origin': 'bool',
        'compress': 'CompressResponse',
        'rules': 'list[Rules]'
    }

    attribute_map = {
        'ignore_url_parameter': 'ignore_url_parameter',
        'follow_origin': 'follow_origin',
        'compress': 'compress',
        'rules': 'rules'
    }

    def __init__(self, ignore_url_parameter=None, follow_origin=None, compress=None, rules=None):
        """CacheConfig - a model defined in huaweicloud sdk"""
        
        

        self._ignore_url_parameter = None
        self._follow_origin = None
        self._compress = None
        self._rules = None
        self.discriminator = None

        if ignore_url_parameter is not None:
            self.ignore_url_parameter = ignore_url_parameter
        if follow_origin is not None:
            self.follow_origin = follow_origin
        if compress is not None:
            self.compress = compress
        if rules is not None:
            self.rules = rules

    @property
    def ignore_url_parameter(self):
        """Gets the ignore_url_parameter of this CacheConfig.

        是否忽略url中的参数。

        :return: The ignore_url_parameter of this CacheConfig.
        :rtype: bool
        """
        return self._ignore_url_parameter

    @ignore_url_parameter.setter
    def ignore_url_parameter(self, ignore_url_parameter):
        """Sets the ignore_url_parameter of this CacheConfig.

        是否忽略url中的参数。

        :param ignore_url_parameter: The ignore_url_parameter of this CacheConfig.
        :type: bool
        """
        self._ignore_url_parameter = ignore_url_parameter

    @property
    def follow_origin(self):
        """Gets the follow_origin of this CacheConfig.

        缓存规则是否遵循源站

        :return: The follow_origin of this CacheConfig.
        :rtype: bool
        """
        return self._follow_origin

    @follow_origin.setter
    def follow_origin(self, follow_origin):
        """Sets the follow_origin of this CacheConfig.

        缓存规则是否遵循源站

        :param follow_origin: The follow_origin of this CacheConfig.
        :type: bool
        """
        self._follow_origin = follow_origin

    @property
    def compress(self):
        """Gets the compress of this CacheConfig.


        :return: The compress of this CacheConfig.
        :rtype: CompressResponse
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this CacheConfig.


        :param compress: The compress of this CacheConfig.
        :type: CompressResponse
        """
        self._compress = compress

    @property
    def rules(self):
        """Gets the rules of this CacheConfig.

        缓存规则，将覆盖之前的规则配置。规则为空重置为默认规则。

        :return: The rules of this CacheConfig.
        :rtype: list[Rules]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this CacheConfig.

        缓存规则，将覆盖之前的规则配置。规则为空重置为默认规则。

        :param rules: The rules of this CacheConfig.
        :type: list[Rules]
        """
        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CacheConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.0.52-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/cache_config.py <==
# coding: utf-8

import re
import six





class CacheConfig:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'ignore_url_parameter': 'bool',
        'follow_origin': 'bool',
        'compress': 'CompressResponse',
        'rules': 'list[Rules]'
    }

    attribute_map = {
        'ignore_url_parameter': 'ignore_url_parameter',
        'follow_origin': 'follow_origin',
        'compress': 'compress',
        'rules': 'rules'
    }

    def __init__(self, ignore_url_parameter=None, follow_origin=None, compress=None, rules=None):
        """CacheConfig - a model defined in huaweicloud sdk"""
        
        

        self._ignore_url_parameter = None
        self._follow_origin = None
        self._compress = None
        self._rules = None
        self.discriminator = None

        if ignore_url_parameter is not None:
            self.ignore_url_parameter = ignore_url_parameter
        if follow_origin is not None:
            self.follow_origin = follow_origin
        if compress is not None:
            self.compress = compress
        if rules is not None:
            self.rules = rules

    @property
    def ignore_url_parameter(self):
        """Gets the ignore_url_parameter of this CacheConfig.

        是否忽略url中的参数。

        :return: The ignore_url_parameter of this CacheConfig.
        :rtype: bool
        """
        return self._ignore_url_parameter

    @ignore_url_parameter.setter
    def ignore_url_parameter(self, ignore_url_parameter):
        """Sets the ignore_url_parameter of this CacheConfig.

        是否忽略url中的参数。

        :param ignore_url_parameter: The ignore_url_parameter of this CacheConfig.
        :type: bool
        """
        self._ignore_url_parameter = ignore_url_parameter

    @property
    def follow_origin(self):
        """Gets the follow_origin of this CacheConfig.

        缓存规则是否遵循源站

        :return: The follow_origin of this CacheConfig.
        :rtype: bool
        """
        return self._follow_origin

    @follow_origin.setter
    def follow_origin(self, follow_origin):
        """Sets the follow_origin of this CacheConfig.

        缓存规则是否遵循源站

        :param follow_origin: The follow_origin of this CacheConfig.
        :type: bool
        """
        self._follow_origin = follow_origin

    @property
    def compress(self):
        """Gets the compress of this CacheConfig.


        :return: The compress of this CacheConfig.
        :rtype: CompressResponse
        """
        return self._compress

    @compress.setter
    def compress(self, compress):
        """Sets the compress of this CacheConfig.


        :param compress: The compress of this CacheConfig.
        :type: CompressResponse
        """
        self._compress = compress

    @property
    def rules(self):
        """Gets the rules of this CacheConfig.

        缓存规则，将覆盖之前的规则配置。规则为空重置为默认规则。

        :return: The rules of this CacheConfig.
        :rtype: list[Rules]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this CacheConfig.

        缓存规则，将覆盖之前的规则配置。规则为空重置为默认规则。

        :param rules: The rules of this CacheConfig.
        :type: list[Rules]
        """
        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CacheConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
